/*
 * Copyright (C) 2002 Roman Zippel <zippel@linux-m68k.org>
 * Released under the terms of the GNU GPL v2.0.
 */

#include <qlistview.h>

class ConfigList;

class ConfigItem : public QListViewItem {
	typedef class QListViewItem Parent;
public:
	ConfigItem(QListView *parent, ConfigItem *after, struct menu *m)
	: Parent(parent, after), menu(m)
	{
		init();
	}
	ConfigItem(ConfigItem *parent, ConfigItem *after, struct menu *m)
	: Parent(parent, after), menu(m)
	{
		init();
	}
	~ConfigItem(void);
	void init(void);
#if QT_VERSION >= 300
	void okRename(int col);
#endif
	void updateMenu(void);
	ConfigList* listView() const
	{
		return (ConfigList*)Parent::listView();
	}

	struct menu *menu;
#if QT_VERSION < 300
	void setEnabled(bool b)
	{
		enabled = b;
	}
	bool enabled;
#endif
};

class ConfigLineEdit : public QLineEdit {
	Q_OBJECT
	typedef class QLineEdit Parent;
public:
	ConfigLineEdit(QWidget * parent)
	: QLineEdit(parent)
	{ }
	void show(ConfigItem *i);
	void keyPressEvent(QKeyEvent *e);
signals:
	void lineChanged(ConfigItem *item);

public:
	ConfigItem *item;
};

class ConfigList : public QListView {
	Q_OBJECT
	typedef class QListView Parent;
public:
	ConfigList(QWidget *p);
	void reinit(void);

	ConfigLineEdit *lineEdit;

	bool showAll(void) const
	{
		return _showAll;
	}
	bool showName(void) const
	{
		return _showName;
	}
	bool showRange(void) const
	{
		return _showRange;
	}
	bool showData(void) const
	{
		return _showData;
	}
protected:
	void keyPressEvent(QKeyEvent *e);
public slots:
	void setShowAll(bool b);
	void setShowName(bool b);
	void setShowRange(bool b);
	void setShowData(bool b);

	void updateList(ConfigItem *item);
	void setValue(QListViewItem* item, const QPoint& pnt, int c);
	void changeValue(QListViewItem* item);
signals:
	void showAllChanged(bool showAll);
	void showNameChanged(bool showName);
	void showRangeChanged(bool showRange);
	void showDataChanged(bool showData);

public:
	void updateListAll(void)
	{
		updateAll = true;
		updateList(NULL);
		updateAll = false;
	}
private:
	bool _showAll;
	bool _showName;
	bool _showRange;
	bool _showData;
public:
	int promptColIdx;
	int nameColIdx;
	int noColIdx;
	int modColIdx;
	int yesColIdx;
	int dataColIdx;
	bool updateAll;
};

class ConfigView : public QVBox {
	Q_OBJECT
public:
	ConfigView(void);
public slots:
	void setHelp(QListViewItem* item);
	void toggleShowAll(void);
	void updateShowAll(bool showAll);
	void toggleShowName(void);
	void updateShowName(bool showName);
	void toggleShowRange(void);
	void updateShowRange(bool showRange);
	void toggleShowData(void);
	void updateShowData(bool showData);

protected:
	void closeEvent(QCloseEvent *e);

	ConfigList *configList;
	QTextView *helpText;
	QPopupMenu *optionMenu;
	int showAllId;
	int showNameId;
	int showRangeId;
	int showDataId;
};
